==> mythdvd_0.16.orig.tar.gz: mythdvd-0.16/i18n/mythdvd_fr.ts <==
<!DOCTYPE TS><TS>
<context>
    <name>DVDRipBox</name>
    <message>
        <source>Your connection to the Myth Transcoding Daemon has gone away. This is not a good thing.</source>
        <translation>Votre connection au service d&apos;encodage de Myth a été intérrompue. Ce n&apos;est pas une bonne chose.</translation>
    </message>
    <message>
        <source>Cannot connect to your Myth Transcoding Daemon. You can try hitting any number key to start it. If you still see this message, then something is really wrong.</source>
        <translation>Impossible de se connecter au service d&apos;encodage de Myth. Vous pouvez essayer de appuyer sur une touche numérique pour le lancer. Si vous voyez toujours ce message, c&apos;est que quelque chose ne fonctionne pas correctement.</translation>
    </message>
    <message>
        <source>Attempting to connect to your mtd said host not found. This is unrecoverably bad. </source>
        <translation>La tentative de connection au service d&apos;encodage de Myth dit que l&apos;hôte n&apos;a pas été trouvé.</translation>
    </message>
    <message>
        <source>Socket communication errors. This is unrecoverably bad. </source>
        <translation>Erreur de socket de communication.</translation>
    </message>
    <message>
        <source>Something is wrong, but I don&apos;t know what.</source>
        <translation>Quelque chose ne va pas, mais je ne sais pas quoi.</translation>
    </message>
    <message>
        <source>Job %1 of %2</source>
        <translation>Tâche %1 sur %2</translation>
    </message>
    <message>
        <source>No jobs and nothing else to do. You could hit 0 to rip a DVD.</source>
        <translation>Pas de tâche en cours et rien d&apos;autre à faire. Vous pouvez appuyer sur 0 pour copier un DVD.</translation>
    </message>
    <message>
        <source>No Jobs. Checking and/or waiting for DVD.</source>
        <translation>Pas de tâche. En attente d&apos;un DVD.</translation>
    </message>
    <message>
        <source>No jobs and nothing else to do. You could hit 0 to rip a disc if you like.</source>
        <translation>Pas de tâche et rien d&apos;autre à faire. Vous pouvez appuyer sur 0 pour copier un DVD si vous le voulez.</translation>
    </message>
    <message>
        <source>Cancelling ...</source>
        <translation>Annulation ...</translation>
    </message>
    <message>
        <source>0 New Rip</source>
        <translation>0 Nouvelle copie</translation>
    </message>
    <message>
        <source>9 Cancel Job</source>
        <translation>9 Annuler la tâche</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>

You have no VCD Player command defined.</source>
        <translation>Vous n&apos;avez pas défini de commande pour le lecteur VCD.</translation>
    </message>
    <message>
        <source>OK, I&apos;ll go run Setup</source>
        <translation>Ok, je vais lancer la configuration.</translation>
    </message>
    <message>
        <source>

You have no VCD Device defined.</source>
        <translation>Vous n&apos;avez pas défini de périphérique VCD.</translation>
    </message>
    <message>
        <source>

You have no DVD Player command defined.</source>
        <translation>Vous n&apos;avez pas défini de commande pour le lecteur DVD.</translation>
    </message>
    <message>
        <source>

You have no DVD Device defined.</source>
        <translation>Vous n&apos;avez pas défini de périphérique DVD.</translation>
    </message>
    <message>
        <source>Location of VCD device</source>
        <translation>Périphérique VCD</translation>
    </message>
    <message>
        <source>This device must exist, and the user running MythDVD needs to have read permission on the device.</source>
        <translation>Ce périphérique doit exister et l&apos;utilisateur de MythDVD doit avoir la permission en lecture sur le périphérique.</translation>
    </message>
    <message>
        <source>Location of DVD device</source>
        <translation>Périphérique DVD</translation>
    </message>
    <message>
        <source>General Settings</source>
        <translation>Configuration générale</translation>
    </message>
    <message>
        <source>DVD Player Command</source>
        <translation>Lecteur DVD</translation>
    </message>
    <message>
        <source>This can be any command to launch a DVD player (e.g. MPlayer, ogle, etc.). If present, %d will be substituted for the DVD device (e.g. /dev/dvd).</source>
        <translation>C&apos;est la commande qui lance le lecteur DVD (i.e. MPlayer,ogle, etc...). Si %d est présent, il sera remplacé par le périphérique DVD (i.e. /dev/dvd).</translation>
    </message>
    <message>
        <source>VCD Player Command</source>
        <translation>Lecteur VCD</translation>
    </message>
    <message>
        <source>This can be any command to launch a VCD player (e.g. MPlayer, xine, etc.). If present, %d will be substituted for the VCD device (e.g. /dev/cdrom).</source>
        <translation>C&apos;est la commande qui lance le lecteur VCD (i.e. MPlayer, xine, etc ...). Si %d est présent, il sera remplacé par le périphérique VCD (i.e. /dev/cdrom).</translation>
    </message>
    <message>
        <source>DVD Player Settings</source>
        <translation>Configuration du lecteur DVD</translation>
    </message>
    <message>
        <source>VCD Player Settings</source>
        <translation>Configuration du lecteur VCD</translation>
    </message>
    <message>
        <source>Directory to hold temporary files</source>
        <translation type="unfinished">Répertoire temporaire</translation>
    </message>
    <message>
        <source>This directory must exist, and the user running MythDVD needs to have write permission to the directory.</source>
        <translation>Ce repertoire doit exister et l&apos;utilisateur de MythDVD doit avoire la permission en écriture sur ce repertoire.</translation>
    </message>
    <message>
        <source>Title Playing Command</source>
        <translation>Lecture du titre</translation>
    </message>
    <message>
        <source>This is a command used to preview a given title on a DVD. If present %t will be set to the title, %d for device, %a for audio track, %c for audio channels.</source>
        <translation>Cette commande est utilisé lors de l&apos;aperçu d&apos;un titre donné d&apos;un DVD. Si %t est présent, il sera remplacé par le titre, %d pare le périphérique, %a par la piste audio, %c par les canaux audios.</translation>
    </message>
    <message>
        <source>Subtitle arguments:</source>
        <translation type="unfinished">Arguments de sous-titrage:</translation>
    </message>
    <message>
        <source>If you choose any subtitles for ripping, this command is added to the end of the Title Play Command to allow previewing of subtitles. If  present %s will be set to the subtitle track. </source>
        <translation>Si vous choisissez un sous-titre pour l&apos;encodage, cette commande est ajouté à la fin de la commande de lecture  du titre pour la prévisualisation du sous-titre.</translation>
    </message>
    <message>
        <source>Base transcode command</source>
        <translation>Commande de base de transcode</translation>
    </message>
    <message>
        <source>This is the base (without arguments) command to run transcode on your system.</source>
        <translation type="unfinished">C&apos;est la commande de base (sans arguments) pour executer transcode (i.e. /usr/bin/transcode).</translation>
    </message>
    <message>
        <source>MTD port number</source>
        <translation>N° de port de MTD</translation>
    </message>
    <message>
        <source>The port number that should be used for communicating with the MTD (Myth Transcoding Daemon)</source>
        <translation>Ce numéro de port est utiliser pour communiquer avec le service d&apos;encodage de Myth (MTD - Myth Transcoding Deamon)</translation>
    </message>
    <message>
        <source>MTD logs to terminal window</source>
        <translation>Logger MTD dans la fenêtre du terminal</translation>
    </message>
    <message>
        <source>If set, the MTD (Myth Transcoding Daemon) will log to the window it is started from. Otherwise, it will write to a file called  mtd.log in the top level ripping directory.</source>
        <translation>Si coché, le service d&apos;encodage de Myth (MTD) affichera la log dans la fenêtre dans laquelle il est executé. Sinon il ecrira dans le fichier mtd.log dans le repertoire de copie/encodage.</translation>
    </message>
    <message>
        <source>Transcode AC3 Audio</source>
        <translation>Encodage en AC3 audio</translation>
    </message>
    <message>
        <source>If set, the MTD (Myth Transcoding Daemon) will, by default, preserve AC3 (Dolby Digital) audio in transcoded files. </source>
        <translation>Si coché, le service d&apos;encodage de Myth (MTD) gardera par defaut le son en qualité AC3 (Dolby Digital) dans les fichiers encodés.</translation>
    </message>
    <message>
        <source>Use xvid rather than divx</source>
        <translation>Utilisé xvid plutôt que divx</translation>
    </message>
    <message>
        <source>If set, mythdvd will use the (open, free) xvid codec rather than divx whenever possible.</source>
        <translation>Si coché, mythdvd utilisera le format d&apos;encodage (ouvert et gratuit) xvid plutôt que divx lorsque cela est possible.</translation>
    </message>
    <message>
        <source>Nice level for MTD</source>
        <translation>Niveau de priorité de MTD</translation>
    </message>
    <message>
        <source>This determines the priority of the Myth Transcoding Daemon. Higher numbers mean lower priority (more CPU to other tasks).</source>
        <translation>Cela détermine la priorité du service d&apos;encodage de Myth. Plus le nombre est élevé, plus la priorité est basse (plus de CPU pour les autres processus).</translation>
    </message>
    <message>
        <source>Ripped video segments</source>
        <translation>Taille maximale des segments</translation>
    </message>
    <message>
        <source>If set to something other than 0, ripped video titles will be broken up into files of this size (in MB). Applies to both perfect quality recordings and intermediate files used for transcoding.</source>
        <translation>Si la valeur est différente de 0, les fichiers d&apos;encodage seront segmentés en fichier de cette taille (en Mo).Cette option est appliquée aux encodage parfait et aux fichiers intermédiaires utilisés pour l&apos;encodage</translation>
    </message>
    <message>
        <source>DVD Ripper Settings</source>
        <translation>Configuration de la copie de DVD</translation>
    </message>
    <message>
        <source>MTD Settings</source>
        <translation>MTD Configuration</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Unconnu</translation>
    </message>
    <message>
        <source>Waiting For Access to DVD</source>
        <translation>En attente d&apos;acces au DVD</translation>
    </message>
    <message>
        <source>Ripping to file ~</source>
        <translation>Copie vers un fichier ~</translation>
    </message>
    <message>
        <source>Perfect DVD Rip of %1</source>
        <translation>Parfaite copie DVD de %1</translation>
    </message>
    <message>
        <source>Transcode of %1</source>
        <translation>Encodage de %1</translation>
    </message>
    <message>
        <source>Waiting for Permission to Start Transcoding</source>
        <translation>En attente de permission pour commencer l&apos;encodage</translation>
    </message>
    <message>
        <source>Transcoding Pass 1 of 2 ~</source>
        <translation>Encodage de la passe 1 sur 2 ~</translation>
    </message>
    <message>
        <source>Transcoding Pass 2 of 2 ~</source>
        <translation>Encodage de la passe 2 sur 2 ~</translation>
    </message>
    <message>
        <source>Transcoding ~</source>
        <translation>Encodage ~</translation>
    </message>
    <message>
        <source>Transcode is thinking </source>
        <translation>Transcode réfléchit</translation>
    </message>
    <message>
        <source>Simultaneous Transcode Jobs</source>
        <translation>Encodage simultanées</translation>
    </message>
    <message>
        <source>This determines the number of simultaneous transcode jobs. If set at 1 (the default), there will only be one active job at a time.</source>
        <translation>Cela determine le nombre de tâches d&apos;encodage simultanées. Si la valeur est 1 (par défaut), il n&apos;y aurra qu&apos;un tâche active au même moment.</translation>
    </message>
</context>
<context>
    <name>ThemeUI</name>
    <message>
        <source>Rip/Transcode</source>
        <translation>Copie/Encodage</translation>
    </message>
    <message>
        <source>Job 1 of 1</source>
        <translation>Tâche 1 sur 1</translation>
    </message>
    <message>
        <source>Length:</source>
        <translation>Durée:</translation>
    </message>
    <message>
        <source>Select:</source>
        <translation>Copié:</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation>Nom:</translation>
    </message>
    <message>
        <source>Quality:</source>
        <translation>Qualité:</translation>
    </message>
    <message>
        <source>Audio Track:</source>
        <translation>Piste Audio:</translation>
    </message>
    <message>
        <source>AC3 Audio:</source>
        <translation>AC3 Audio:</translation>
    </message>
    <message>
        <source>Subtitles:</source>
        <translation>Sous-titres:</translation>
    </message>
    <message>
        <source>View:</source>
        <translation>Prévisualisation:</translation>
    </message>
    <message>
        <source>Title 1 of 1</source>
        <translation>Titre 1 sur 1</translation>
    </message>
    <message>
        <source>0:00:00</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>TitleDialog</name>
    <message>
        <source>Unkown</source>
        <translation>Inconnu</translation>
    </message>
    <message>
        <source>%1 - Title %2</source>
        <translation>%1 - Titre %2</translation>
    </message>
    <message>
        <source>Perfect</source>
        <translation>Parfaite</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Aucun</translation>
    </message>
    <message>
        <source>Title %1 of %2</source>
        <translation>Titre %1 sur %2</translation>
    </message>
    <message>
        <source>0 Process Selected Title</source>
        <translation>0 Encoder le titre selectionné</translation>
    </message>
    <message>
        <source>0 Process Selected Titles</source>
        <translation>0 Encoder les titres selectionnés</translation>
    </message>
</context>
</TS>

==> mythdvd_0.17.orig.tar.gz: mythdvd-0.17/i18n/mythdvd_fr.ts <==
<!DOCTYPE TS><TS>
<context>
    <name>DVDRipBox</name>
    <message>
        <source>Your connection to the Myth Transcoding Daemon has gone away. This is not a good thing.</source>
        <translation>Votre connexion au service d&apos;encodage de Myth a été interrompue. Ce n&apos;est pas une bonne chose.</translation>
    </message>
    <message>
        <source>Cannot connect to your Myth Transcoding Daemon. You can try hitting any number key to start it. If you still see this message, then something is really wrong.</source>
        <translation>Impossible de se connecter au service d&apos;encodage de Myth. Vous pouvez essayer d&apos;appuyer sur une touche numérique pour le lancer. Si vous voyez toujours ce message, c&apos;est que quelque chose ne fonctionne pas correctement.</translation>
    </message>
    <message>
        <source>Attempting to connect to your mtd said host not found. This is unrecoverably bad. </source>
        <translation>La tentative de connexion au service d&apos;encodage de Myth dit que l&apos;hôte n&apos;a pas été trouvé.</translation>
    </message>
    <message>
        <source>Socket communication errors. This is unrecoverably bad. </source>
        <translation>Erreur de &apos;socket&apos; de communication.</translation>
    </message>
    <message>
        <source>Something is wrong, but I don&apos;t know what.</source>
        <translation>Quelque chose ne va pas, mais je ne sais pas quoi.</translation>
    </message>
    <message>
        <source>Job %1 of %2</source>
        <translation>Tâche %1 sur %2</translation>
    </message>
    <message>
        <source>No jobs and nothing else to do. You could hit 0 to rip a DVD.</source>
        <translation>Pas de tâche en cours et rien d&apos;autre à faire. Vous pouvez appuyer sur 0 pour copier un DVD.</translation>
    </message>
    <message>
        <source>No Jobs. Checking and/or waiting for DVD.</source>
        <translation>Pas de tâche. En attente d&apos;un DVD.</translation>
    </message>
    <message>
        <source>No jobs and nothing else to do. You could hit 0 to rip a disc if you like.</source>
        <translation>Pas de tâche et rien d&apos;autre à faire. Vous pouvez appuyer sur 0 pour copier un DVD si vous le voulez.</translation>
    </message>
    <message>
        <source>Cancelling ...</source>
        <translation>Annulation ...</translation>
    </message>
    <message>
        <source>0 New Rip</source>
        <translation>0 Nouvelle copie</translation>
    </message>
    <message>
        <source>9 Cancel Job</source>
        <translation>9 Annuler la tâche</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>

You have no VCD Player command defined.</source>
        <translation>

Vous n&apos;avez pas défini de commande pour le lecteur VCD.</translation>
    </message>
    <message>
        <source>OK, I&apos;ll go run Setup</source>
        <translation>Ok, je vais lancer la configuration.</translation>
    </message>
    <message>
        <source>

You have no VCD Device defined.</source>
        <translation>

Vous n&apos;avez pas défini de périphérique VCD.</translation>
    </message>
    <message>
        <source>

You have no DVD Player command defined.</source>
        <translation>

Vous n&apos;avez pas défini de commande pour le lecteur DVD.</translation>
    </message>
    <message>
        <source>

You have no DVD Device defined.</source>
        <translation>

Vous n&apos;avez pas défini de périphérique DVD.</translation>
    </message>
    <message>
        <source>Location of VCD device</source>
        <translation>Chemin du périphérique VCD</translation>
    </message>
    <message>
        <source>This device must exist, and the user running MythDVD needs to have read permission on the device.</source>
        <translation>Ce périphérique doit exister et l&apos;utilisateur de MythDVD doit avoir la permission en lecture sur le périphérique.</translation>
    </message>
    <message>
        <source>Location of DVD device</source>
        <translation>Chemin du périphérique DVD</translation>
    </message>
    <message>
        <source>General Settings</source>
        <translation>Configuration générale</translation>
    </message>
    <message>
        <source>DVD Player Command</source>
        <translation>Commande du lecteur de DVD</translation>
    </message>
    <message>
        <source>This can be any command to launch a DVD player (e.g. MPlayer, ogle, etc.). If present, %d will be substituted for the DVD device (e.g. /dev/dvd).</source>
        <translation>C&apos;est la ligne de commande qui lance le lecteur DVD (i.e. MPlayer,ogle, etc...). Si %d est présent dans la ligne de commande, il sera remplacé par le périphérique DVD (i.e. /dev/dvd).</translation>
    </message>
    <message>
        <source>VCD Player Command</source>
        <translation>Commande du Lecteur VCD</translation>
    </message>
    <message>
        <source>This can be any command to launch a VCD player (e.g. MPlayer, xine, etc.). If present, %d will be substituted for the VCD device (e.g. /dev/cdrom).</source>
        <translation>C&apos;est la ligne de commande qui lance le lecteur VCD (i.e. MPlayer, xine, etc ...). Si %d est présent dans la ligne de commande, il sera remplacé par le périphérique VCD (i.e. /dev/cdrom).</translation>
    </message>
    <message>
        <source>DVD Player Settings</source>
        <translation>Configuration du lecteur DVD</translation>
    </message>
    <message>
        <source>VCD Player Settings</source>
        <translation>Configuration du lecteur VCD</translation>
    </message>
    <message>
        <source>Directory to hold temporary files</source>
        <translation>Répertoire de stockage temporaire</translation>
    </message>
    <message>
        <source>This directory must exist, and the user running MythDVD needs to have write permission to the directory.</source>
        <translation>Ce répertoire doit exister et l&apos;utilisateur de MythDVD doit avoir la permission en écriture sur ce répertoire.</translation>
    </message>
    <message>
        <source>Title Playing Command</source>
        <translation>Commande de lecture du titre</translation>
    </message>
    <message>
        <source>This is a command used to preview a given title on a DVD. If present %t will be set to the title, %d for device, %a for audio track, %c for audio channels.</source>
        <translation>Cette ligne de commande est utilisé lors de l&apos;aperçu du titre d&apos;un DVD donné. Dans cette ligne de commande, %t est remplacé par le titre, %d par le périphérique, %a par la piste audio, %c par les canaux audio.</translation>
    </message>
    <message>
        <source>Subtitle arguments:</source>
        <translation>Arguments de sous-titrage:</translation>
    </message>
    <message>
        <source>If you choose any subtitles for ripping, this command is added to the end of the Title Play Command to allow previewing of subtitles. If  present %s will be set to the subtitle track. </source>
        <translation>Si vous choisissez un sous-titre pour l&apos;encodage, cette commande est ajouté à la fin de la commande de lecture afin de prévisualiser le sous-titre. si %s est présent, il sera remplacé par le sous titre sélectionné</translation>
    </message>
    <message>
        <source>Base transcode command</source>
        <translation>Commande de base de transcode</translation>
    </message>
    <message>
        <source>This is the base (without arguments) command to run transcode on your system.</source>
        <translation>C&apos;est la commande de base (sans arguments) pour exécuter transcode (i.e. /usr/bin/transcode).</translation>
    </message>
    <message>
        <source>MTD port number</source>
        <translation>N° de port de MTD (MythTranscode Daemon)</translation>
    </message>
    <message>
        <source>The port number that should be used for communicating with the MTD (Myth Transcoding Daemon)</source>
        <translation>Ce numéro de port est utiliser pour communiquer avec le service d&apos;encodage de Myth (MTD - Myth Transcoding Deamon)</translation>
    </message>
    <message>
        <source>MTD logs to terminal window</source>
        <translation>Tracer le MTD (MythTranscode Daemon) dans la fenêtre du terminal</translation>
    </message>
    <message>
        <source>If set, the MTD (Myth Transcoding Daemon) will log to the window it is started from. Otherwise, it will write to a file called  mtd.log in the top level ripping directory.</source>
        <translation>Si coché, le service d&apos;encodage de Myth (MTD) affichera des diagnostics dans la fenêtre dans laquelle il est exécuté. Sinon il écrira dans le fichier mtd.log situé à la racine du répertoire de copie.</translation>
    </message>
    <message>
        <source>Transcode AC3 Audio</source>
        <translation>Encodage en Audio AC3</translation>
    </message>
    <message>
        <source>If set, the MTD (Myth Transcoding Daemon) will, by default, preserve AC3 (Dolby Digital) audio in transcoded files. </source>
        <translation>Si coché, le service d&apos;encodage de Myth (MTD) gardera par défaut le son en qualité AC3 (Dolby Digital) dans les fichiers encodés.</translation>
    </message>
    <message>
        <source>Use xvid rather than divx</source>
        <translation>Utiliser xvid plutôt que divx</translation>
    </message>
    <message>
        <source>If set, mythdvd will use the (open, free) xvid codec rather than divx whenever possible.</source>
        <translation>Si coché, mythdvd utilisera le format d&apos;encodage (ouvert et gratuit) xvid plutôt que divx lorsque cela est possible. </translation>
    </message>
    <message>
        <source>Nice level for MTD</source>
        <translation>Niveau de priorité de MTD</translation>
    </message>
    <message>
        <source>This determines the priority of the Myth Transcoding Daemon. Higher numbers mean lower priority (more CPU to other tasks).</source>
        <translation>Cela détermine la priorité du service d&apos;encodage de Myth (MTD). Plus le nombre est élevé, plus la priorité est basse (plus de CPU pour les autres processus).</translation>
    </message>
    <message>
        <source>Ripped video segments</source>
        <translation>Taille maximale des segments vidéo</translation>
    </message>
    <message>
        <source>If set to something other than 0, ripped video titles will be broken up into files of this size (in MB). Applies to both perfect quality recordings and intermediate files used for transcoding.</source>
        <translation>Si la valeur est différente de 0, les fichiers d&apos;encodage seront segmentés en fichiers de cette taille (en Mo).Cette option est appliquée aux encodages en qualité parfaite et aux fichiers intermédiaires utilisés pour l&apos;encodage.</translation>
    </message>
    <message>
        <source>DVD Ripper Settings</source>
        <translation>Configuration de la copie de DVD</translation>
    </message>
    <message>
        <source>MTD Settings</source>
        <translation>MTD Configuration</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Inconnu</translation>
    </message>
    <message>
        <source>Waiting For Access to DVD</source>
        <translation>En attente d&apos;accès au DVD</translation>
    </message>
    <message>
        <source>Ripping to file ~</source>
        <translation>Copie vers un fichier ~</translation>
    </message>
    <message>
        <source>Perfect DVD Rip of %1</source>
        <translation>Parfaite copie DVD de %1</translation>
    </message>
    <message>
        <source>Transcode of %1</source>
        <translation>Encodage de %1</translation>
    </message>
    <message>
        <source>Waiting for Permission to Start Transcoding</source>
        <translation>En attente de permission pour commencer l&apos;encodage</translation>
    </message>
    <message>
        <source>Transcoding Pass 1 of 2 ~</source>
        <translation>Encodage de la passe 1 sur 2 ~</translation>
    </message>
    <message>
        <source>Transcoding Pass 2 of 2 ~</source>
        <translation>Encodage de la passe 2 sur 2 ~</translation>
    </message>
    <message>
        <source>Transcoding ~</source>
        <translation>Encodage ~</translation>
    </message>
    <message>
        <source>Transcode is thinking </source>
        <translation>Transcode réfléchit</translation>
    </message>
    <message>
        <source>Simultaneous Transcode Jobs</source>
        <translation>Encodage simultanée des tâches</translation>
    </message>
    <message>
        <source>This determines the number of simultaneous transcode jobs. If set at 1 (the default), there will only be one active job at a time.</source>
        <translation>Cela détermine le nombre de tâches d&apos;encodage simultanées. Si la valeur est 1 (par défaut), il n&apos;y aura qu&apos;une tâche active au même moment.</translation>
    </message>
    <message>
        <source>On DVD insertion</source>
        <translation>Sur insertion de DVD</translation>
    </message>
    <message>
        <source>Display mythdvd menu menu</source>
        <translation type="obsolete">Affiche le menu &apos;menu de mythdvd&apos;</translation>
    </message>
    <message>
        <source>Do nothing</source>
        <translation>Ne rien faire</translation>
    </message>
    <message>
        <source>Play DVD</source>
        <translation>Jouer le DVD</translation>
    </message>
    <message>
        <source>Rip DVD</source>
        <translation>Importer le DVD</translation>
    </message>
    <message>
        <source>Media Monitoring should be turned on to allow this feature (Setup -&gt; General -&gt; CD/DVD Monitor</source>
        <translation>Le paramètre de surveillance des périphériques doit être activé pour pouvoir utiliser cette fonction (Paramètrage-&gt;général-&gt;Surveillance de CD/DVD)</translation>
    </message>
    <message>
        <source>Display mythdvd menu</source>
        <translation>Affiche le menu mythdvd</translation>
    </message>
</context>
<context>
    <name>ThemeUI</name>
    <message>
        <source>Rip/Transcode</source>
        <translation>Copie/Encodage</translation>
    </message>
    <message>
        <source>Job 1 of 1</source>
        <translation>Tâche 1 sur 1</translation>
    </message>
    <message>
        <source>Length:</source>
        <translation>Durée:</translation>
    </message>
    <message>
        <source>Select:</source>
        <translation>Copié:</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation>Nom:</translation>
    </message>
    <message>
        <source>Quality:</source>
        <translation>Qualité:</translation>
    </message>
    <message>
        <source>Audio Track:</source>
        <translation>Piste Audio:</translation>
    </message>
    <message>
        <source>AC3 Audio:</source>
        <translation>Audio AC3:</translation>
    </message>
    <message>
        <source>Subtitles:</source>
        <translation>Sous-titres:</translation>
    </message>
    <message>
        <source>View:</source>
        <translation>Vue:</translation>
    </message>
    <message>
        <source>Title 1 of 1</source>
        <translation>Titre 1 sur 1</translation>
    </message>
    <message>
        <source>0:00:00</source>
        <translation>0:00:00</translation>
    </message>
</context>
<context>
    <name>TitleDialog</name>
    <message>
        <source>Unkown</source>
        <translation>Inconnu</translation>
    </message>
    <message>
        <source>%1 - Title %2</source>
        <translation>%1 - Titre %2</translation>
    </message>
    <message>
        <source>Perfect</source>
        <translation>Parfaite</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Aucun</translation>
    </message>
    <message>
        <source>Title %1 of %2</source>
        <translation>Titre %1 sur %2</translation>
    </message>
    <message>
        <source>0 Process Selected Title</source>
        <translation>0 Encoder le titre sélectionné</translation>
    </message>
    <message>
        <source>0 Process Selected Titles</source>
        <translation>0 Encoder les titres sélectionnés</translation>
    </message>
</context>
</TS>
